@@ -57,7 +57,7 @@
 #define DefN template <typename Num, typename X = std::enable_if_t< std::is_integral<Num>::value || std::is_floating_point<Num>::value>>
 #define DefI template <typename Num, typename X = std::enable_if_t< std::is_integral<Num>::value >>
 #define DefS template <typename S, typename X = std::enable_if_t < std::is_convertible<std::remove_const_t<std::remove_reference_t<S>>, const T* >::value || std::is_constructible<std::remove_const_t<std::remove_reference_t<S>>, const T*>::value ||  std::is_convertible<S, std::basic_string<T> >::value>>
-#define DefT template <typename CharT, typename X = std::enable_if_t< std::is_same<CharT, char>::value || std::is_same<CharT, wchar_t>::value  >>
+#define DefT template <typename CharT, typename X = std::enable_if_t< (std::is_same<CharT, char>::value || std::is_same<CharT, wchar_t>::value)>>
 
 template <typename T>
 class CTextT
@@ -110,9 +110,9 @@ public:
 
     friend CTextT operator+(const CTextT& string1, const CTextT& string2)    { return Add(string1, string2); }
     friend CTextT operator+(const CTextT& string, const T* str)              { return Add(string, str); }
-    friend CTextT operator+(const T* str, const CTextT& string)              { return Add(string, str); }
+    friend CTextT operator+(const T* str, const CTextT& string)              { return Add(str, string); }
     friend CTextT operator+(const CTextT& string, T ch)                      { return Add(string, ch); }
-    friend CTextT operator+(T ch, const CTextT& string)                      { return Add(string, ch); }
+    friend CTextT operator+(T ch, const CTextT& string)                      { return Add(ch, string); }
 
     const CTextT& operator+=(const T* str);
     const CTextT& operator+=(const CTextT& string);
@@ -181,7 +181,6 @@ public:
     bool         containAny(const T* cList, bool bCase = true) const; // returns true if our string contains any of the characters of the list
     bool         containOnly(const T* cList, bool bCase = true) const; // returns true if our string contains only characters from the list   
     bool         contain(const T c, size_t from, size_t to) const; // search in range
-    bool         convertToHex(const T* sep = SPACE);  // convert string to hex values, "Hello World" ---> "48 65 6C 6C 6F 20 57 6F 72 6C 64"
     void	     copyTo(T* s);  //copy the string data to the external buffer (should be large enough)
     void	     copyTo(T* s, size_t max_len); //copy the string data to the external buffer (should be large enough)
     size_t       count(T c, size_t from = 0) const;  //returns the count of occurences of the given character
@@ -208,11 +207,12 @@ public:
     CTextT&      cutEnds(size_t fromLeft, size_t fromRight);  //cut number of charcters from left and right
     CTextT&      cutLeft(size_t count);  //removes count characters from left
     CTextT&      cutRight(size_t count); //cut number of characters from right, if count is too big empty the string
+    CTextT&		 enclose(T c);  // enclose with same character
     CTextT&      enclose(T begin, T end, bool checkEnds = true); //enclose with the provided character separators (if not already ends and begins with them)
     CTextT&      enclose(const T* begin, const T* end, bool checkEnds = true); //enclose with the provided text separators (if not already ends and begins with them)
     CTextT&      equal(const CTextT& s);  // make our string equal to str
     CTextT&      equal(const T* s);  // make equal to str
-    CTextT&      equal(T c, size_t len);  // init witb len number of ch
+    CTextT&      equal(T c, size_t len);  // init with len number of ch
     CTextT&      equal(const T* s, size_t len, size_t offset = 0);  // init to len characters from string at offset   
     bool         endsWith(T c, size_t from = 0, bool bCase = true) const;
     DefS bool    endsWith(const S& s, size_t from = 0, bool bCase = true) const; // return true if ends with the provided string
@@ -233,7 +233,8 @@ public:
     bool         format(const T* format, ...);
     DefN bool    fromBinary(Num i);  // create a binary string from the number
     DefI bool    fromInteger(Num i, bool append = false, int padd = 0, T paddValue = T('0')); // convert the decimal integer to string
-    DefN bool    fromHex(Num i, bool hasBase = true, bool upper = false, bool append = false); // create a hexadecimal string from the number
+    bool         fromHex(const T* s); // reverse of toHex, text "48 65 6C 6C 6F 20 57 6F 72 6C 64" --> "HelloWorld" 
+    DefN bool    fromHexNumber(Num i, bool hasBase = true, bool upper = false, bool append = false); // create a hexadecimal string from the number
     bool         fromDouble(double d, int precision = 6, bool fixed = true, bool nozeros = false, bool append = false);
     bool         fromSingle(const char* s);  // init with single-char ANSI string, make string -> wstring convert if necessary
     bool         fromWide(const wchar_t* s);  // init with UNICODE string, make wstring -> string convert if necessary
@@ -406,7 +407,8 @@ inline const T*  str(size_t from = 0) const; //return pointer to modifiable buff
     CTextT       substringRight(size_t from) const; // return new string with all characters starting at a zero-based index and continuing to the end
     CTextT       substringLeft(size_t count) const;  // returns new string with count characters from left
     void		 terminatePath(); //makes sure that path ends with slash
-  unsigned int   toBinaryNumber(bool& bOk); //if the string contains a binary number, convert it   
+  unsigned int   toBinary(bool& bOk); //if the string contains a binary number, convert it   
+  bool           toHex(const T* sep = SPACE);  // convert string to hex values, "Hello World" ---> "48 65 6C 6C 6F 20 57 6F 72 6C 64"
   unsigned int   toHexNumber(bool& bOk);  //if the string contains a hex number convert it , "1E" --> 30  
     double       toDouble(bool& bOk) const;
     int          toInteger(bool& bOk) const;
@@ -449,7 +451,9 @@ inline const T*  str(size_t from = 0) const; //return pointer to modifiable buff
     // static routines
     static CTextT<T>  Add(const CTextT&, const CTextT&);  // returns the concatenation of the both strings
     static CTextT<T>  Add(const CTextT&, const T*);
+    static CTextT<T>  Add(const T*, const CTextT&);
     static CTextT<T>  Add(const CTextT&, T c);
+    static CTextT<T>  Add(T c, const CTextT<T>& str);
     static bool       ArePermutation(const CTextT& a, const CTextT& b);
     static CTextT<T>  GetDir(const T* path);
     ContC static size_t  GeneratePermutations(C& container, CTextT& s);
