@@ -67,7 +67,7 @@ PYBIND11_MODULE(ctextlib, m)
         .def("cutEnds", (CTextA& (CTextA::*)(size_t)) &CTextA::cutEnds, "remove count of characters from left and right", py::arg("count"))
         .def("cutLeft", &CTextA::cutLeft, "removes count characters from left", py::arg("count"))
         .def("cutRight", &CTextA::cutRight, "removes count characters from left", py::arg("count"))
-        .def("enclose", [](CTextA& s, const char* c)->CTextA& {return s.enclose(c[0]); }, "enclose with same character", py::arg("c"))
+        .def("enclose", [](CTextA& s, const char* str)->CTextA& {return s.enclose(str,str); }, "enclose with same character", py::arg("c"))
         .def("enclose", (CTextA& (CTextA::*)(const char* begin, const char* end, bool checkEnds)) &CTextA::enclose, "enclose with the provided text separators (if not already ends and begins with them)", py::arg("begin"), py::arg("end"), py::arg("checkEnds") = true)          
         .def("endsWith", [](CTextA& s, const char* str, bool bCase)->bool { return s.endsWith(str, 0, bCase); }, "return true if ends with the provided string", py::arg("str"), py::arg("case") = true)
         .def("endsWithAny", [](CTextA& s, const vector<string>& list, bool bCase)->bool { return s.endsWithAny(list, 0, bCase, true); }, "returns true if ends with any of the strings from the list", py::arg("list"), py::arg("case") = true)
@@ -246,7 +246,7 @@ PYBIND11_MODULE(ctextlib, m)
         .def("cutEnds", (CTextU& (CTextU::*)(size_t)) &CTextU::cutEnds, "remove count of characters from left and right", py::arg("count"))
         .def("cutLeft", &CTextU::cutLeft, "removes count characters from left", py::arg("count"))
         .def("cutRight", &CTextU::cutRight, "removes count characters from left", py::arg("count"))
-        .def("enclose", [](CTextU& s, const wchar_t* c)->CTextU& {return s.enclose(c[0]); }, "enclose with same character", py::arg("c"))
+        .def("enclose", [](CTextU& s, const wchar_t* str)->CTextU& {return s.enclose(str, str); }, "enclose with same character", py::arg("c"))
         .def("enclose", (CTextU& (CTextU::*)(const wchar_t* begin, const wchar_t* end, bool checkEnds)) &CTextU::enclose, "enclose with the provided text separators (if not already ends and begins with them)", py::arg("begin"), py::arg("end"), py::arg("checkEnds") = true)
         .def("endsWith", [](CTextU& s, const wchar_t* str, bool bCase)->bool { return s.endsWith(str, 0, bCase); }, "return true if ends with the provided string", py::arg("str"), py::arg("case") = true)
         .def("endsWithAny", [](CTextU& s, const vector<wstring>& list, bool bCase)->bool { return s.endsWithAny(list, 0, bCase, true); }, "returns true if ends with any of the strings from the list", py::arg("list"), py::arg("case") = true)
